module.exports = function () {
    var JobFairModel = require('../../modal/admin/JobFairModel')
    var JobCentreModel = require('../../modal/web/JobCentreModel')
    var SubscriptionModel = require('../../modal/web/SubscriptionModel')





    this.addOneJobFairDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            const JobFairModelObject = new JobFairModel(data)
            JobFairModelObject.save(function (error, result) {
                if (error) {
                    console.log(error)
                    response.error = true
                } else {
                    response.error = false
                    response.data = result
                }
                resolve(response)
            })
        })
    }





    this.getTotalJobFairListDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobFairModel.find({
                    is_active: 1
                })
                .count()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }



    this.getJobFairListDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobFairModel.aggregate([{
                        $match: {
                            $expr: {
                                $eq: ["$is_active", 1]
                            }
                        }
                    },
                    {
                        $sort: {
                            createdAt: -1
                        }
                    },
                    {
                        $skip: data.pageNumber > 0 ? ((data.pageNumber - 1) * 10) : 0
                    },
                    {
                        $limit: data.RowsPerpage
                    },
                    {
                        $project: {
                            _id: 1,
                            thumbNail_url: 1,
                            // backGround_imageUrl: 1,
                            title: 1,
                            description: {
                                $substrBytes: ["$description", 0, 250]
                            },
                            is_active: 1,
                            createdAt: 1,
                        }
                    }
                ])
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }



    this.viewOneJobFairDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobFairModel.findOne({
                    is_active: 1,
                    _id: data.jobFairPost_id
                })
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }


    this.editOneSurveyDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobFairModel.updateOne({
                    _id: data.jobFairPost_id
                }, {
                    $set: {
                        title: data.title,
                        thumbNail_url: data.thumbNail_url,
                        backGround_imageUrl: data.backGround_imageUrl,
                        description: data.description,
                    }
                })
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }



    this.deleteOneJobFairDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobFairModel.deleteOne({
                    _id: data.jobFairPost_id
                })
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

    this.getTotalSubscriptionListDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            SubscriptionModel.find({
                    is_active: 1
                })
                .count()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

    this.getALLSubscriptionListDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            var typeFilter = {
                is_active: 1
            }

            if (data.typeFilter.length > 0) {
                typeFilter = {
                    post_type: data.typeFilter
                }
            }

            SubscriptionModel.aggregate([{
                        $match: {
                            $and: [{
                                    $expr: {
                                        $eq: ["$is_active", 1]
                                    }
                                },
                                {
                                    user_name: {
                                        $regex: `${data.search}`,
                                        $options: 'i'
                                    }
                                },
                                typeFilter
                            ]
                        }
                    },
                    {
                        $sort: {
                            createdAt: -1
                        }
                    },
                    {
                        $skip: data.pageNumber > 0 ? ((data.pageNumber - 1) * 10) : 0
                    },
                    {
                        $limit: parseInt(data.RowsPerpage)
                    },
                    {
                        $project: {
                            _id: 1,
                            user_name: 1,
                            post_id: 1,
                            post_type: 1,
                            // subscription_validity: 1,
                            // subscription_validity_type: 1,
                            // start_time: 1,
                            // end_time: 1,
                            status: {
                                $cond: {
                                    if: {
                                        $gte: ["$end_time", new Date()]
                                    },
                                    then: "Active",
                                    else: "Expired"
                                }
                            },
                            is_active: 1,
                            createdAt: 1,
                        }
                    }
                ])
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }


    this.getOneSubscriptionDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            SubscriptionModel.findOne({
                    is_active: 1,
                    _id: data.subscription_id
                }).lean()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

}