module.exports = function () {
    var BazaarCityModel = require('../../modal/web/BazaarCityModel')
    var MyProfileModal = require('../../modal/web/MyProfileModal')
    var LikesModel = require('../../modal/web/Likes')

    var myProfileModal = require('../../modal/web/MyProfileModal')

    var ShoutOutsModel = require('../../modal/admin/ShoutOutsModel')

    var scheduleLiveModel = require('../../modal/web/scheduleLiveModel')

    var SlotTimeModel = require('../../modal/web/SlotTimeModel')

    var PinoyPreneursModel = require('../../modal/web/PinoyPreneursModel')

    this.addBazaarCityItemDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            const BazaarCityModelObject = new BazaarCityModel(data)
            BazaarCityModelObject.save(function (error, result) {
                if (error) {
                    console.log(error)
                    response.error = true
                } else {
                    response.error = false
                    response.data = result
                }
                resolve(response)
            })
        })
    }


    this.getOneUserDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            MyProfileModal.findOne({
                uid: data.uid
            }, function (error, result) {
                if (error) {
                    console.log(error)
                    response.error = true
                } else {
                    response.error = false
                    response.data = result
                }
                resolve(response)
            })
        })
    }

    this.getOnePinoyPreneurDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            PinoyPreneursModel.findOne({
                uid: data.uid,
                end_time: {
                    $gte: new Date()
                },
            }, function (error, result) {
                if (error) {
                    console.log(error)
                    response.error = true
                } else {
                    response.error = false
                    response.data = result
                }
                resolve(response)
            })
        })
    }

    this.GetTotalBazaarCityListCountDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            var categories = {
                is_active: 1
            }

            if (data.categories.length > 0) {
                categories = {
                    category: {
                        $in: data.categories
                    }
                }
            }
            BazaarCityModel.find({
                    $and: [{
                            is_active: 1
                        }, {
                            $or: [{
                                    item_name: {
                                        $regex: `${data.search}`,
                                        $options: 'i'
                                    }
                                },
                                {
                                    full_name: {
                                        $regex: `${data.search}`,
                                        $options: 'i'
                                    }
                                },
                                {
                                    category: {
                                        $regex: `${data.search}`,
                                        $options: 'i'
                                    }
                                }
                            ]
                        },
                        categories
                    ]
                })
                .count()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }


    this.GetBazaarCityListDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            var categories = {
                is_active: 1
            }

            if (data.categories.length > 0) {
                categories = {
                    category: {
                        $in: data.categories
                    }
                }
                // console.log("categories")

            }
            BazaarCityModel.aggregate([{
                        $match: {
                            $and: [{
                                    $expr: {
                                        $eq: ["$is_active", 1]
                                    }
                                },
                                {
                                    $or: [{
                                            item_name: {
                                                $regex: `${data.search}`,
                                                $options: 'i'
                                            }
                                        },
                                        {
                                            full_name: {
                                                $regex: `${data.search}`,
                                                $options: 'i'
                                            }
                                        },
                                        {
                                            category: {
                                                $regex: `${data.search}`,
                                                $options: 'i'
                                            }
                                        }
                                    ]
                                },
                                categories
                            ]

                        }
                    },
                    {
                        $sort: {
                            createdAt: -1
                        }
                    },
                    {
                        $skip: data.pageNumber > 0 ? ((data.pageNumber - 1) * 10) : 0
                    },
                    {
                        $limit: 10
                    },
                    {
                        $project: {
                            _id: 1,
                            uid: 1,
                            item_name: 1,
                            item_images: 1,
                            category: 1,
                            price: 1,
                            post_description: 1,
                            province_name: 1,
                            profile_photo: 1,
                            full_name: 1,
                            number_of_likes: 1,
                            number_of_comments: 1,
                            is_active: 1,
                            createdAt: 1,

                        }
                    }

                ])
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

    this.GetOneBazaarCityPostDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            BazaarCityModel.find({
                    is_active: 1,
                    _id: data.bazzarCityPost_id
                })
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

    this.getOneProfileDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            myProfileModal.findOne({
                    uid: data.uid
                }).lean()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

    this.GetOneBazaarCityLikedDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            LikesModel.findOne({
                    is_active: 1,
                    uid: data.uid,
                    post_id: data.bazzarCityPost_id
                }, {
                    _id: 1,
                    uid: 1

                }).then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }


    this.checkFeaturePostDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            BazaarCityModel.find({
                    is_active: 1,
                    _id: data.bazzarCityPost_id,
                    uid: data.uid
                }).count()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }



    this.checkUserFeaturePostDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            ShoutOutsModel.find({
                    is_active: 1,
                    post_id: data.bazzarCityPost_id,
                    uid: data.uid
                }).count()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }





    this.PostSchduleLiveDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            const scheduleLiveModelObject = new scheduleLiveModel(data)
            scheduleLiveModelObject.save(function (error, result) {
                if (error) {
                    console.log(error)
                    response.error = true
                } else {
                    response.error = false
                    response.data = result
                }
                resolve(response)
            })
        })
    }



    this.GetTotalScheduleLiveListCountDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {

            scheduleLiveModel.find({
                    $and: [{
                            is_active: 1
                        },
                        // {
                        //     start_time: {
                        //         $lte: new Date()
                        //     }
                        // },
                        {
                            end_time: {
                                $gte: new Date()
                            }
                        },
                        // {
                        //     $or: [{
                        //             item_name: {
                        //                 $regex: `${data.search}`,
                        //                 $options: 'i'
                        //             }
                        //         },
                        //         {
                        //             full_name: {
                        //                 $regex: `${data.search}`,
                        //                 $options: 'i'
                        //             }
                        //         },
                        //         {
                        //             category: {
                        //                 $regex: `${data.search}`,
                        //                 $options: 'i'
                        //             }
                        //         }
                        //     ]
                        // },
                    ]
                })
                .count()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }


    this.GetAllScheduleLiveListDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {

            scheduleLiveModel.aggregate([{
                        $match: {
                            $and: [{
                                    $expr: {
                                        $eq: ["$is_active", 1]
                                    }
                                },
                                // {
                                //     start_time: {
                                //         $lte: new Date()
                                //     }
                                // },
                                {
                                    end_time: {
                                        $gte: new Date()
                                    }
                                },

                            ]

                        }
                    },

                    {
                        $skip: data.pageNumber > 0 ? ((data.pageNumber - 1) * 10) : 0
                    },
                    {
                        $limit: 10
                    },
                    {
                        $project: {
                            _id: 1,
                            uid: 1,
                            time_slot: 1,
                            title: 1,
                            short_description: 1,
                            live_date: 1,
                            // province_name: 1,
                            start_time: 1,
                            end_time: 1,
                            profile_photo: 1,
                            full_name: 1,
                            payment_status: 1,
                            is_active: 1,
                            slotId: 1,
                            createdAt: 1,
                            // priority: {
                            //     "$eq": [
                            //         "$province_name",
                            //         data.province
                            //     ]
                            // }
                        }
                    },
                    {
                        $sort: {
                            // priority: -1,
                            start_time: 1
                        }
                    }
                ])
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

    this.GetOneScheduleLiveDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {

            scheduleLiveModel.aggregate([{
                        $match: {
                            $and: [{
                                    $expr: {
                                        $eq: ["$is_active", 1]
                                    }
                                },
                                {
                                    start_time: {
                                        $lte: new Date()
                                    }
                                },
                                {
                                    end_time: {
                                        $gte: new Date()
                                    }
                                },

                            ]

                        }
                    },

                    // {
                    //     $skip: data.pageNumber > 0 ? ((data.pageNumber - 1) * 10) : 0
                    // },
                    {
                        $lookup: {
                            from: "pinoypreneurs",
                            let: {
                                userId: "$uid"
                            },
                            pipeline: [{
                                $match: {
                                    $expr: {
                                        $and: [{
                                            $eq: ["$uid", "$$userId"]
                                        }]
                                    }
                                }
                            }],
                            as: "business_details"
                        }
                    },
                    {
                        $limit: 1
                    },
                    {
                        $unwind: "$business_details"
                    },
                    {
                        $project: {
                            _id: 1,
                            uid: 1,
                            time_slot: 1,
                            title: 1,
                            short_description: 1,
                            live_date: 1,
                            // province_name: 1,
                            start_time: 1,
                            end_time: 1,
                            profile_photo: 1,
                            full_name: 1,
                            payment_status: 1,
                            is_active: 1,
                            slotId: 1,
                            createdAt: 1,
                            business_details: 1
                            // priority: {
                            //     "$eq": [
                            //         "$province_name",
                            //         data.province
                            //     ]
                            // }
                        }
                    },
                    {
                        $sort: {
                            // priority: -1,
                            start_time: -1
                        }
                    }
                ])
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }


    this.slotTimeListDao = async (data) => {
        console.log(data.date)
        var response = {}
        return new Promise(function (resolve, reject) {
            SlotTimeModel.aggregate([{
                        $match: {
                            $and: [{
                                $expr: {
                                    $eq: ["$is_active", 1]
                                }
                            }]
                        }
                    },
                    {
                        $lookup: {
                            from: "schedulelives",
                            let: {
                                slot_Id: '$slot_id',
                                active: '$is_active',
                            },
                            pipeline: [{
                                $match: {
                                    $expr: {
                                        $and: [{
                                            $eq: ["$slotId", "$$slot_Id"],
                                            // $eq: ["$live_date", data.date],
                                        }, ]
                                    }
                                }
                            }],
                            as: "slot"
                        }
                    },
                    // {
                    //     $unwind: "$slot"
                    // },
                    {
                        $sort: {
                            _id: 1,
                            slot_id: 1
                        }
                    },

                    {
                        "$addFields": {
                            "booked": {
                                "$arrayElemAt": [{
                                    "$filter": {
                                        "input": "$slot",
                                        "as": "timeslot",
                                        "cond": {
                                            "$eq": ["$$timeslot.live_date", data.date]
                                        }
                                    }
                                }, 0]
                            }
                        }
                    },
                    {
                        $project: {
                            _id: 1,
                            slot_time: 1,
                            slot_id: 1,
                            is_active: 1,
                            // slot: 1,
                            // booked: 1,
                            isReserved: {
                                $cond: {
                                    if: {
                                        "$eq": [
                                            "$booked.live_date",
                                            data.date
                                        ]
                                    },
                                    then: 1,
                                    else: 0
                                }
                            },

                        }
                    }
                ])
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }


    this.postSlotDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            const SlotTimeModelObject = new SlotTimeModel(data)
            SlotTimeModelObject.save(function (error, result) {
                if (error) {
                    console.log(error)
                    response.error = true
                } else {
                    response.error = false
                    response.data = result
                }
                resolve(response)
            })
        })
    }



    this.getOneScheduleDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            scheduleLiveModel.findOne({
                    // time_slot:data.time_slot,
                    live_date: data.live_date,
                    slotId: data.slot_id
                }).lean()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }



}