module.exports = function () {
    var JobCentreModel = require('../../modal/web/JobCentreModel')
    var MyProfileModal = require('../../modal/web/MyProfileModal')
    var jobCentreDraftModel = require('../../modal/web/jobCentreDraftModel')
    var JobFairModel = require('../../modal/admin/JobFairModel')
    var SubscriptionModel = require('../../modal/web/SubscriptionModel')
    var SubscriptionPlansModel = require('../../modal/admin/SubscriptionPlansModel')
    var paymentHistory = require('../../modal/web/paymentHistory')







    this.addJobPostDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            const JobCentreModelObject = new JobCentreModel(data)
            JobCentreModelObject.save(function (error, result) {
                if (error) {
                    console.log(error)
                    response.error = true
                } else {
                    response.error = false
                    response.data = result
                }
                resolve(response)
            })
        })
    }


    this.getOneProfileDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            MyProfileModal.findOne({
                uid: data.uid
            }, function (error, result) {
                if (error) {
                    console.log(error)
                    response.error = true
                } else {
                    response.error = false
                    response.data = result
                }
                resolve(response)
            })
        })
    }



    this.getTotalJobListDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            var typesOfIndustry = {
                is_active: 1
            }
            var locations = {
                is_active: 1
            }
            var jobType = {
                is_active: 1
            }

            if (data.typesOfIndustry.length > 0) {
                typesOfIndustry = {
                    industry: {
                        $in: data.typesOfIndustry
                    }
                }
            }
            if (data.locations.length > 0) {
                locations = {
                    province_name: {
                        $in: data.locations
                    }
                }
            }
            if (data.jobType.length > 0) {
                jobType = {
                    working_type: {
                        $in: data.jobType
                    }
                }
            }
            JobCentreModel.find({
                    $and: [{
                            is_active: 1
                        }, {
                            $or: [{
                                    company_name: {
                                        $regex: `${data.search}`,
                                        $options: 'i'
                                    }
                                },
                                {
                                    job_position: {
                                        $regex: `${data.search}`,
                                        $options: 'i'
                                    }
                                },
                            ]
                        }, {
                            end_time: {
                                $gte: new Date()
                            }
                        },
                        typesOfIndustry,
                        locations,
                        jobType,
                        {
                            payment_status: "complete"
                        }
                    ]
                })
                .count()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }


    this.getAllJobListDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            var typesOfIndustry = {
                is_active: 1
            }
            var locations = {
                is_active: 1
            }
            var jobType = {
                is_active: 1
            }

            if (data.typesOfIndustry.length > 0) {
                typesOfIndustry = {
                    industry: {
                        $in: data.typesOfIndustry
                    }
                }
            }
            if (data.locations.length > 0) {
                locations = {
                    province_name: {
                        $in: data.locations
                    }
                }
            }
            if (data.jobType.length > 0) {
                jobType = {
                    working_type: {
                        $in: data.jobType
                    }
                }
            }
            JobCentreModel.aggregate([{
                        $match: {
                            $and: [{
                                    $expr: {
                                        $eq: ["$is_active", 1]
                                    }
                                },
                                {
                                    $or: [{
                                        $or: [{
                                                company_name: {
                                                    $regex: `${data.search}`,
                                                    $options: 'i'
                                                }
                                            },
                                            {
                                                job_position: {
                                                    $regex: `${data.search}`,
                                                    $options: 'i'
                                                }
                                            },
                                        ]
                                    }]
                                },
                                {
                                    end_time: {
                                        $gte: new Date()
                                    }
                                },
                                typesOfIndustry,
                                locations,
                                jobType,
                                {
                                    payment_status: "complete"
                                }
                            ]

                        }
                    },
                    {
                        $skip: data.pageNumber > 0 ? ((data.pageNumber - 1) * 10) : 0
                    },
                    {
                        $limit: 10
                    },
                    {
                        $project: {
                            _id: 1,
                            uid: 1,
                            job_id: 1,
                            company_name: 1,
                            job_position: 1,
                            industry: 1,
                            job_description: {
                                $substrBytes: ["$job_description", 0, 160]
                            },
                            working_type: 1,
                            number_of_position_available: 1,
                            late_date_to_apply: 1,
                            province_name: 1,
                            posted_by: 1,
                            job_constraint: 1,
                            how_to_apply: 1,
                            payment_status: 1,
                            end_time:1,
                            is_active: 1,
                            createdAt: 1,
                        }
                    },
                    {
                        $sort: {
                            createdAt: -1
                        }
                    },
                ])
                // .skip(data.pageNumber > 0 ? ((data.pageNumber - 1) * 10) : 0)
                // .limit(10)
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }




    this.getOneJobPostDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobCentreModel.findOne({
                    is_active: 1,
                    _id: data.job_Post_id
                })
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

    this.getOneJobpostDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobCentreModel.find({
                is_active: 1,
            }).
            sort({
                createdAt: -1
            }).
            limit(1)
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }



    this.getOneJobDraftDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            jobCentreDraftModel.findOne({
                    is_active: 1,
                    uid: data.uid
                })
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }



    this.addJobDraftDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            const JobCentreModelObject = new jobCentreDraftModel(data)
            JobCentreModelObject.save(function (error, result) {
                if (error) {
                    console.log(error)
                    response.error = true
                } else {
                    response.error = false
                    response.data = result
                }
                resolve(response)
            })
        })
    }


    this.updateJobDraftDao = async (data, id) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            jobCentreDraftModel.updateOne({
                    _id: id
                }, {
                    $set: data
                })
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

    this.getTotalJobFairListDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobFairModel.find({
                    is_active: 1
                })
                .count()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }




    this.getJobFairListDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobFairModel.aggregate([{
                        $match: {
                            $expr: {
                                $eq: ["$is_active", 1]
                            }
                        }
                    },
                    {
                        $sort: {
                            createdAt: -1
                        }
                    },
                    // {
                    //     $skip: data.pageNumber > 0 ? ((data.pageNumber - 1) * 10) : 0
                    // },
                    {
                        $limit: 10
                    },
                    {
                        $project: {
                            _id: 1,
                            thumbNail_url: 1,
                            // backGround_imageUrl: 1,
                            title: 1,
                            description: {
                                $substrBytes: ["$description", 0, 250]
                            },
                            is_active: 1,
                            createdAt: 1,
                        }
                    }
                ])
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }


    this.addJobPostSubscriptionDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            const SubscriptionModelobject = new SubscriptionModel(data)
            SubscriptionModelobject.save(function (error, result) {
                if (error) {
                    console.log(error)
                    response.error = true
                } else {
                    response.error = false
                    response.data = result
                }
                resolve(response)
            })
        })
    }

    this.getSubscriptionDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            SubscriptionPlansModel.findOne({
                    is_active: 1,
                    post_type: 'jobPost'
                }).lean()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }



    this.editOneJobPostDao = async (data,obj) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobCentreModel.updateOne({
                _id:data.post_id
            }, {
                $set: obj
            })
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

    this.getOneSubscriptionDetailDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            SubscriptionPlansModel.findOne({
                    is_active: 1,
                    post_type:"jobPost"
                })
                .lean()
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }


    this.clearJobDraftDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            jobCentreDraftModel.deleteOne({
                    is_active: 1,
                    uid: data.uid
                })
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }


    this.updatePostStatusDao = async (obj) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobCentreModel.updateOne({
                _id:obj.post_id
            }, {
                $set: {
                        payment_status: "complete",
                        payment_ref_id:obj.payment_ref_id
                }
            })
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

    this.savePaymentDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            const paymentHistoryObject = new paymentHistory(data)
            paymentHistoryObject.save(function (error, result) {
                if (error) {
                    console.log(error)
                    response.error = true
                } else {
                    response.error = false
                    response.data = result
                }
                resolve(response)
            })
        })
    }

    this.getOneJobFairDao = async (data) => {
        var response = {}
        return new Promise(function (resolve, reject) {
            JobFairModel.findOne({
                is_active: 1,
                _id:data.id
            })
                .then((result) => {
                    response.error = false
                    response.result = result
                    // console.log(result);
                    resolve(response)

                })
                .catch((error) => {
                    response.error = true
                    resolve(response)

                    console.log(error);
                });
        })
    }

}